@@ -1,9 +1,6 @@
-// Copyright (C) 2009 NICTA
-// Copyright (C) 2009 Dimitrios Bouzas
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
-// - Dimitrios Bouzas (dimitris dot mpouzas at gmail dot com)
+// Copyright (C) 2009-2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2009-2010 Conrad Sanderson
+// Copyright (C) 2009-2010 Dimitrios Bouzas
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -23,7 +20,7 @@
 template<typename T1>
 inline
 const Op<T1, op_cov>
-cov(const Base<typename T1::elem_type,T1>& X, const u32 norm_type = 0)
+cov(const Base<typename T1::elem_type,T1>& X, const uword norm_type = 0)
   {
   arma_extra_debug_sigprint();
   
@@ -37,7 +34,7 @@ cov(const Base<typename T1::elem_type,T1>& X, const u32 norm_type = 0)
 template<typename T1, typename T2>
 inline
 const Glue<T1,T2,glue_cov>
-cov(const Base<typename T1::elem_type,T1>& A, const Base<typename T1::elem_type,T2>& B, const u32 norm_type = 0)
+cov(const Base<typename T1::elem_type,T1>& A, const Base<typename T1::elem_type,T2>& B, const uword norm_type = 0)
   {
   arma_extra_debug_sigprint();
   
